@@ -29,9 +29,9 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
+	chv1 "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
+	"github.com/open-cluster-management/multicloud-operators-channel/pkg/utils"
 	dplv1 "github.com/open-cluster-management/multicloud-operators-deployable/pkg/apis/apps/v1"
-	chv1 "github.com/stolostron/multicloud-operators-channel/pkg/apis/apps/v1"
-	"github.com/stolostron/multicloud-operators-channel/pkg/utils"
 )
 
 const (
@@ -265,7 +265,7 @@ var _ = Describe("object bucket controller", func() {
 			Expect(err).NotTo(HaveOccurred())
 
 			myStoreage := &utils.FakeObjectStore{}
-			myStoreage.InitObjectStoreConnection("", "", "")
+			myStoreage.InitObjectStoreConnection("", "", "", "")
 
 			chReg.SetObjectStorageForChannel(chn, myStoreage)
 
